#
# spec file for package python-openpyxl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-openpyxl
Version:        2.2.2
Release:        5.2
Summary:        A Python library to read/write Excel 2007 xlsx/xlsm files
License:        MIT and Python-2.0
Group:          Development/Languages/Python
Url:            http://openpyxl.readthedocs.org
Source:         http://pypi.python.org/packages/source/o/openpyxl/openpyxl-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-jdcal
BuildRequires:  python-setuptools
BuildRequires:  python-xml
Requires:       python-jdcal
Requires:       python-xml
# for embedded image support
Recommends:     python-Pillow
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
openpyxl is a pure python reader and writer of Excel OpenXML files.
It is ported from the PHPExcel project

%prep
%setup -q -n openpyxl-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv LICENCE.rst LICENSE.rst

%files
%defattr(-,root,root,-)
%doc AUTHORS.rst LICENSE.rst README.rst
%{python_sitelib}/*

%changelog
* Fri May  8 2015 benoit.monin@gmx.fr
- update to version 2.2.2:
  * #447 Uppercase datetime number formats not recognised.
  * #453 Borders broken in shared_styles.
- additional changes from version 2.2.1:
  * PR54 Improved precision on times near midnight.
  * PR55 Preserve macro buttons
  * #429 Workbook fails to load because header and footers cannot
    be parsed.
  * #433 File-like object with encoding=None
  * #434 SyntaxError when writing page breaks.
  * #436 Read-only mode duplicates empty rows.
  * #437 Cell.offset raises an exception
  * #438 Cells with pivotButton and quotePrefix styles cannot be
    read
  * #440 Error when customised versions of builtin formats
  * #442 Exception raised when a fill element contains no children
  * #444 Styles cannot be copied
- additional changes from version 2.2.0:
  * #415 Improved exception when passing in invalid in memory files.
- additional changes from version 2.2.0-b1:
  * Cell styles deprecated, use formatting objects (fonts, fills,
    borders, etc.) directly instead
  * Charts will no longer try and calculate axes by default
  * Support for template file types - PR21
  * Moved ancillary functions and classes into utils package -
    single place of reference
  * PR 34 Fully support page setup
  * Removed SAX-based XML Generator. Special thanks to Elias Rabel
    for implementing xmlfile for xml.etree
  * Preserve sheet view definitions in existing files (frozen
    panes, zoom, etc.)
  * #103 Set the zoom of a sheet
  * #199 Hide gridlines
  * #215 Preserve sheet view setings
  * #262 Set the zoom of a sheet
  * #392 Worksheet header not read
  * #387 Cannot read files without styles.xml
  * #410 Exception when preserving whitespace in strings
  * #417 Cannot create print titles
  * #420 Rename confusing constants
  * #422 Preserve color index in a workbook if it differs from the
    standard
  * Use a 2-way cache for column index lookups
  * Clean up tests in cells
  * PR 40 Support frozen panes and autofilter in write-only mode
  * Use ws.calculate_dimension(force=True) in read-only mode for
    unsized worksheets
- additional changes from version 2.1.5:
  * #403 Cannot add comments in write-only mode
  * #401 Creating cells in an empty row raises an exception
  * #408 from_excel adjustment for Julian dates 1 < x < 60
  * #409 refersTo is an optional attribute
  * Allow cells to be appended to standard worksheets for code
    compatibility with write-only mode.
- additional changes from version 2.1.4:
  * #393 IterableWorksheet skips empty cells in rows
  * #394 Date format is applied to all columns (while only first
    column contains dates)
  * #395 temporary files not cleaned properly
  * #396 Cannot write “=” in Excel file
  * #398 Cannot write empty rows in write-only mode with LXML
    installed
  * Add relation namespace to root element for compatibility with
    iWork
  * Serialize comments relation in LXML-backend
- additional changes from version 2.1.3:
  * PR 31 Correct tutorial
  * PR 32 See #380
  * PR 37 Bind worksheet to ColumnDimension objects
  * #379 ws.append() doesn’t set RowDimension Correctly
  * #380 empty cells formatted as datetimes raise exceptions
- additional changes from version 2.1.2:
  * PR 30 Fix regex for positive exponentials
  * PR 28 Fix for #328
  * #120, #168 defined names with formulae raise exceptions, #292
  * #328 ValueError when reading cells with hyperlinks
  * #369 IndexError when reading definedNames
  * #372 number_format not consistently applied from styles
- additional changes from version 2.1.1:
  * PR 20 Support different workbook code names
  * Allow auto_axis keyword for ScatterCharts
  * #332 Fills lost in ConditionalFormatting
  * #360 Support value=”none” in attributes
  * #363 Support undocumented value for textRotation
  * #364 Preserve integers in read-only mode
  * #366 Complete read support for DataValidation
  * #367 Iterate over unsized worksheets
- additional changes from version 2.1.0:
  * “read_only” and “write_only” new flags for workbooks
  * Support for reading and writing worksheet protection
  * Support for reading hidden rows
  * Cells now manage their styles directly
  * ColumnDimension and RowDimension object manage their styles
    directly
  * Use xmlfile for writing worksheets if available - around 3
    times faster
  * Datavalidation now part of the worksheet package
  * Number formats are now just strings
  * Strings can be used for RGB and aRGB colours for Fonts, Fills
    and Borders
  * Create all style tags in a single pass
  * Performance improvement when appending rows
  * Cleaner conversion of Python to Excel values
  * PR6 reserve formatting for empty rows
  * standard worksheets can append from ranges and generators
  * #153 Cannot read visibility of sheets and rows
  * #181 No content type for worksheets
  * #153 Cannot read visibility of sheets and rows
  * #181 No content type for worksheets
  * #241 Cannot read sheets with inline strings
  * #322 1-indexing for merged cells
  * #339 Correctly handle removal of cell protection
  * #341 Cells with formulae do not round-trip
  * #347 Read DataValidations
  * #353 Support Defined Named Ranges to external workbooks
- additional changes from version 2.0.5:
  * #348 incorrect casting of boolean strings
  * #349 roundtripping cells with formulae
- additional changes from version 2.0.4:
  * Add a sample file illustrating colours
  * #331 DARKYELLOW was incorrect
  * Correctly handle extend attribute for fonts
- additional changes from version 2.0.3:
  * Updated docs
  * #319 Cannot load Workbooks with vertAlign styling for fonts
- additional changes from version 2.0.2:
  * This is last release that will support Python 3.2
  * Cells are referenced with 1-indexing: A1 == cell(row=1,
    column=1)
  * Use jdcal for more efficient and reliable conversion of
    datetimes
  * Significant speed up when reading files
  * Merged immutable styles
  * Type inference is disabled by default
  * RawCell renamed ReadOnlyCell
  * ReadOnlyCell.internal_value and ReadOnlyCell.value now behave
    the same as Cell
  * Provide no size information on unsized worksheets
  * Lower memory footprint when reading files
  * All tests converted to pytest
  * Pyflakes used for static code analysis
  * Sample code in the documentation is automatically run
  * Support GradientFills
  * BaseColWidth set
  * #70 Add filterColumn, sortCondition support to AutoFilter
  * #80 Reorder worksheets parts
  * #82 Update API for conditional formatting
  * #87 Add support for writing Protection styles, others
  * #89 Better handling of content types when preserving macros
  * #46 ColumnDimension style error
  * #86 reader.worksheet.fast_parse sets booleans to integers
  * #98 Auto sizing column widths does not work
  * #137 Workbooks with chartsheets
  * #185 Invalid PageMargins
  * #230 Using v in cells creates invalid files
  * #243 - IndexError when loading workbook
  * #263 - Forded conversion of line breaks
  * #267 - Raise exceptions when passed invalid types
  * #270 - Cannot open files which use non-standard sheet names or
    reference Ids
  * #269 - Handling unsized worksheets in IterableWorksheet
  * #270 - Handling Workbooks with non-standard references
  * #275 - Handling auto filters where there are only custom filters
  * #277 - Harmonise chart and cell coordinates
  * #280- Explicit exception raising for invalid characters
  * #286 - Optimized writer can not handle a datetime.time value
  * #296 - Cell coordinates not consistent with documentation
  * #300 - Missing column width causes load_workbook() exception
  * #304 - Handling Workbooks with absolute paths for worksheets
    (from Sharepoint)
- additional changes from version 1.8.6:
  * Fixed typo for import Elementtree
  * #279 Incorrect path for comments files on Windows
- additional changes from version 1.8.5:
  * The ‘=’ string is no longer interpreted as a formula
  * When a client writes empty xml tags for cells (e.g.
    <c r=’A1’></c>), reader will not crash
- additional changes from version 1.8.4:
  * #260 better handling of undimensioned worksheets
  * #268 non-ascii in formualae
  * #282 correct implementation of register_namepsace for Python 2.6
- additional changes from version 1.8.3:
  * Always parse using cElementTree
  * Slight improvements in memory use when parsing
  * #256 - error when trying to read comments with optimised reader
  * #260 - unsized worksheets
  * #264 - only numeric cells can be dates
- additional changes from version 1.8.2:
  * #247 - iterable worksheets open too many files
  * #252 - improved handling of lxml
  * #253 - better handling of unique sheetnames
- additional changes from version 1.8.1:
  * #246
- additional changes from version 1.8.0:
  * Support for Python 2.5 dropped.
  * Support conditional formatting
  * Support lxml as backend
  * Support reading and writing comments
  * pytest as testrunner now required
  * Improvements in charts: new types, more reliable
  * load_workbook now accepts data_only to allow extracting values
    only from formulae. Default is false.
  * Images can now be anchored to cells
  * Docs updated
  * Provisional benchmarking
  * Added convenience methods for accessing worksheets and cells by
    key
- add python-jdcal as dependency
- remove python-nose and %%check: tests are not provided in
  the archive anymore
- rename documentation files: changed upstream
- remove CHANGES: not provided anymore
* Thu Jul 17 2014 toddrme2178@gmail.com
- Add LICENSE to %%doc
* Thu Dec  5 2013 p.drouand@gmail.com
- Update to version 1.7.0
  + Read CHANGES file from package documentation
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May 10 2013 toddrme2178@gmail.com
- Initial version
